# INICIAR PROYECTO

```sh
composer create-project symfony/framework-standard-edition symfony/ "3.2.*"
```

# EMPEZAR

En archivo *web/app.php*, en la línea 9, cambiar el segundo parámetro a **true**, para desactivar el modo *dev* en las rutas

```php
$kernel = new AppKernel('prod', true);
```

## 1ª prueba - Controlador para renderizar **HTML**

En el archivo */src/AppBundle/Controller/DefaultController.php*

```php
/**
* @Route("/prueba", name="prueba")
*/
public function pruebaAction(Request $request)
{
    echo "<h1>Hola Mundo</h1>";
    die();
}
```

## 2ª prueba - Controlador para renderizar vista-platilla TWIG

En el archivo */src/AppBundle/Controller/DefaultController.php*, crear en este controlador la función *pruebadosAction*, que permite redenderizar la plantilla *index-dos.html.twig* 
```php
/**
* @Route("/prueba-dos", name="pruebados")
*/
public function pruebadosAction(Request $request)
{
    return $this->render('default/index-dos.html.twig');
}
```

## 3ª prueba - Pasar las rutas de **annotations** a **YML**

Crear estructura de carpetas:

> \src\AppBundle\Resources\config

Crear dentro carpeta config el archivo *routing.yml*

> routing.yml

```yml
app_default:
    resource: "@AppBundle/Resources/config/routing/default.yml"
    prefix: /
```

Crear carpeta *routing*:

> \src\AppBundle\Resources\config\routing

Crear dentro carpeta routing el archivo *default.yml*
> default.yml

```yml
default_prueba_tres:
    path: /prueba-tres
    defaults: { _controller: AppBundle:Default:pruebatres }
```

- **Default:** Nombre controlador
- **pruebatres:** Nombre de la función dentro del controlador Default

En el archivo *app/config/routing.yml*

```yml
app:
    resource: "@AppBundle/Resources/config/routing.yml"
    prefix: /
```

En el archivo */src/AppBundle/Controller/DefaultController.php*

```php
public function pruebatresAction(Request $request)
{
    return $this->render('default/index-tres.html.twig');
}
```

# DATA BASE

Crear la carpeta Entity, con los elementos de la base de datos
```sh
php bin/console doctrine:mapping:import AppBundle yml
php bin/console doctrine:generate:entities AppBundle
```

## 1ª Prueba - Crear el controlador *AlumnoController*

En el directorio */src/AppBundle/Controller/* crear el archivo:

> AlumnoController.php 

```php
<?php

namespace AppBundle\Controller;

use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;

class AlumnoController extends Controller
{
    public function indexAction(Request $request)
    {
        return $this->render('alumno/index.html.twig');
    }
}
```
- Adaptar el routing y crear la vista para este controlador

## 2ª Prueba - Mostrar contenido de BBDD

En */src/AppBundle/Controller/AlumnoController.php*
```php
public function indexAction(Request $request)
{
    $em = $this->getDoctrine()->getManager();
        
    $alumnos_repo=$em->getRepository("AppBundle:Alumno");
    $alumnos=$alumnos_repo->findAll();
        
    return $this->render('alumno/index.html.twig', array(
        'alumnos'=>$alumnos,
    ));
}
```

Crear la vista en TWIG
En *app/Resources/views/alumnos/index.html.twig*
```twig
{% extends 'base.html.twig' %}

{% block body %}

<table>

    <tr>
        <th>Nombre</th>
        <th>Codigo</th>
    </tr>

    {% for alumno in alumnos %}
        {% if alumno.idcodigo.idcodigo == 2 %}
            <tr style="background-color: green; color: #fff;">
        {% else %}
            <tr>
        {% endif %}
            <td>{{ alumno.nombre }}</td>
            <td>{{ alumno.idcodigo.nombre }}</td>
        </tr>
    {% endfor %}

</table>

{% endblock %}
```
## 3ª Prueba - Añadir menú

En *app/Resources/views/base.html.twig*
```html
<nav>
    <a href="{{path("default_prueba_tres")}}">Prueba 3</a>
    <a href="{{path("alumno_index")}}">Alumnos</a>
</nav>
```

